pub unsafe extern "C" fn alloc(size: u64) -> u64Expand description
Allocate memory block of the specified size.
- The size is rounded up to the next multiple of page size.
- The returned address is aligned at a page boundary.
Returns the address of the allocated memory region or 0 if the allocation was
unsuccessful.