pub enum VideoFrameFormat {
Rgb888Indexed8 = 1,
}Expand description
The format of the frames emitted via [yield_video_frame].
Variants
Rgb888Indexed8 = 1
Indexed RGB colors.
Format: [ palette(256*3) | indices(width*height) ].
Each frame consists of a pallete and indices into it.
The pallete has 256 colors and each color has 3 components. Each color in the palette is encoded as a sequence of red, green, blue components, each component occupies 8 bits.
The frame itself goes after the palette. It is encoded as a sequence of 8-bit indices into
the palette in row-major order, there are width * height indices in total.